@@ -47,9 +47,7 @@ class TestExperiment:
         assert experiment.is_distributed == False
 
     def test_read_distributed_experiment(self):
-        distributed_experiment = vessl.read_experiment(
-            pytest.distributed_experiment.number
-        )
+        distributed_experiment = vessl.read_experiment(pytest.distributed_experiment.number)
         assert distributed_experiment.is_distributed == True
 
     def test_read_experiment_by_id(self):
@@ -76,6 +74,4 @@ class TestExperiment:
         with pytest.raises(InvalidExperimentError):
             # Cannot upload to managed experiment
             vessl.upload_experiment_output_files(pytest.experiment.number, "test/fixture")
-        vessl.upload_experiment_output_files(
-            pytest.local_experiment.number, "test/fixture"
-        )
+        vessl.upload_experiment_output_files(pytest.local_experiment.number, "test/fixture")
