@@ -1,10 +1,10 @@
 import os
 import tempfile
+from test.conftest import USE_MOCK
 
 import pytest
 
 import vessl
-from test.conftest import USE_MOCK
 from vessl.util.file_object import UploadableS3Object
 from vessl.util.random import random_string
 
@@ -20,7 +20,7 @@ class TestVolume:
 
         # create an actual file on local
         local_path = os.path.join(tempfile.gettempdir(), self.file_name)
-        with open(local_path, 'w') as f:
+        with open(local_path, "w") as f:
             f.write("dummy")
 
         UploadableS3Object(
