@@ -70,9 +70,7 @@ class SweepParameterType(click.ParamType):
 
         name = tokens[0]
         type = click.Choice(SWEEP_PARAMETER_TYPES).convert(tokens[1], param, ctx)
-        range_type = click.Choice(SWEEP_PARAMETER_RANGE_TYPES).convert(
-            tokens[2], param, ctx
-        )
+        range_type = click.Choice(SWEEP_PARAMETER_RANGE_TYPES).convert(tokens[2], param, ctx)
         values = tokens[3:]
 
         parameter = {"name": name, "type": type}
@@ -109,9 +107,7 @@ def parameter_prompter(ctx: click.Context, param: click.Parameter, value: str) -
         index = len(parameters) + 1
         name = click.prompt(f"Parameter #{index} name")
         type = prompt_choices(f"Parameter #{index} type", SWEEP_PARAMETER_TYPES)
-        range_type = prompt_choices(
-            f"Parameter #{index} range type", SWEEP_PARAMETER_RANGE_TYPES
-        )
+        range_type = prompt_choices(f"Parameter #{index} range type", SWEEP_PARAMETER_RANGE_TYPES)
 
         if range_type == SWEEP_PARAMETER_RANGE_TYPE_LIST:
             values = click.prompt(f"Parameter #{index} values (space separated)")
@@ -251,9 +247,7 @@ def list():
     "--num-failed",
     type=click.INT,
     required=True,
-    prompter=generic_prompter(
-        "Maximum number of experiments to allow to fail", click.INT
-    ),
+    prompter=generic_prompter("Maximum number of experiments to allow to fail", click.INT),
     help="Maximum number of experiments to allow to fail.",
 )
 @vessl_option(
