@@ -14,8 +14,8 @@ from openapi_client.models import (
     OrmHyperparameter,
     ResponseExperimentInfo,
     ResponseExperimentListResponse,
-    StorageFile,
     ResponseGitHubCodeRef,
+    StorageFile,
 )
 from openapi_client.models.orm_execution_environment import OrmExecutionEnvironment
 from vessl import __version__, vessl_api
@@ -103,6 +103,7 @@ def list_experiments(
 def create_experiment(
     cluster_name: str,
     start_command: str,
+    cluster_node_names: List[str] = None,
     kernel_resource_spec_name: str = None,
     processor_type: str = None,
     cpu_limit: float = None,
@@ -138,6 +139,8 @@ def create_experiment(
 
     Args:
         cluster_name(str): Cluster name(must be specified before other options).
+        cluster_node_names(List[str]): Node names. The experiment will run on
+            one of these nodes. Defaults to None(all).
         start_command(str): Start command to execute in experiment container.
         kernel_resource_spec_name(str):  Resource type to run an experiment (for
             managed cluster only). Defaults to None.
@@ -239,11 +242,21 @@ def create_experiment(
             ),
         )
 
+    organization_name = _get_organization_name(**kwargs)
+    cluster_node_ids = None
+    if not cluster.is_savvihub_managed and cluster_node_names:
+        nodes = vessl_api.custom_cluster_node_list_api(
+            organization_name=organization_name,
+            cluster_id=cluster.id,
+        ).nodes
+        cluster_node_ids = [node.id for node in nodes if node.name in cluster_node_names]
+
     return vessl_api.experiment_create_api(
-        organization_name=_get_organization_name(**kwargs),
+        organization_name=organization_name,
         project_name=_get_project_name(**kwargs),
         experiment_create_api_input=ExperimentCreateAPIInput(
             cluster_id=cluster.id,
+            cluster_node_ids=cluster_node_ids,
             hyperparameters=[
                 OrmHyperparameter(key, str(value))
                 for key, value in map(
@@ -269,9 +282,7 @@ def _create_orm_execution_environment():
     try:
         pynvml.nvmlInit()
         gpu_count = pynvml.nvmlDeviceGetCount()
-        gpu_type = pynvml.nvmlDeviceGetName(
-            pynvml.nvmlDeviceGetHandleByIndex(0)
-        ).decode("utf8")
+        gpu_type = pynvml.nvmlDeviceGetName(pynvml.nvmlDeviceGetHandleByIndex(0)).decode("utf8")
     except pynvml.nvml.NVMLError:
         pass
 
@@ -295,9 +306,7 @@ def _create_orm_execution_environment():
     )
 
 
-def create_local_experiment(
-    message: str = None, hyperparameters: dict = None, **kwargs
-):
+def create_local_experiment(message: str = None, hyperparameters: dict = None, **kwargs):
     return vessl_api.local_experiment_create_api(
         local_experiment_create_api_input=LocalExperimentCreateAPIInput(
             execution_environment=_create_orm_execution_environment(),
@@ -518,9 +527,7 @@ def upload_experiment_output_files(experiment_number: int, path: str, **kwargs):
     )
 
 
-def terminate_experiment(
-    experiment_number: int, **kwargs
-) -> ResponseExperimentInfo:
+def terminate_experiment(experiment_number: int, **kwargs) -> ResponseExperimentInfo:
     """Terminate experiment in the default organization/project. If you want to
     override the default organization/project, then pass `organization_name` or
     `project_name` as `**kwargs`.
