@@ -189,9 +189,7 @@ class UserMetricCollector(Collector):
 
     def _read_distributed_info(self) -> Dict[str, int]:
         distributed_info = {}
-        distributed_number = safe_cast(
-            os.environ.get("VESSL_DISTRIBUTED_NUMBER", None), int
-        )
+        distributed_number = safe_cast(os.environ.get("VESSL_DISTRIBUTED_NUMBER", None), int)
         if distributed_number is not None:
             distributed_info = {"distributed_number": distributed_number}
         else:
