@@ -275,9 +275,7 @@ def terminate_sweep(sweep_name: str, **kwargs) -> ResponseSweepInfo:
     )
 
 
-def list_sweep_logs(
-    sweep_name: str, tail: int = 200, **kwargs
-) -> List[InfluxdbSweepLog]:
+def list_sweep_logs(sweep_name: str, tail: int = 200, **kwargs) -> List[InfluxdbSweepLog]:
     """List sweep logs in the default organization/project. If you want to
     override the default organization/project, then pass `organization_name` or
     `project_name` as `**kwargs`.
@@ -334,9 +332,7 @@ def get_best_sweep_experiment(sweep_name: str, **kwargs) -> ResponseSweepExperim
     def best_experiments(
         items: [ResponseSweepExperimentInfo], maximize: bool
     ) -> ResponseSweepExperimentInfo:
-        return sorted(
-            items, key=lambda x: x.objective_metric_value, reverse=maximize
-        ).pop()
+        return sorted(items, key=lambda x: x.objective_metric_value, reverse=maximize).pop()
 
     if sweep_read_response.experiment_summary.total > 0:
         filtered_experiment_summary = []
