@@ -5,9 +5,7 @@ import toml
 from schema import And, Optional, Schema
 
 DEFAULT_VESSL_DIR = os.path.join(str(Path.home()), ".vessl")
-DEFAULT_CONFIG_PATH = os.environ.get(
-    "VESSL_CONFIG_PATH", os.path.join(DEFAULT_VESSL_DIR, "config")
-)
+DEFAULT_CONFIG_PATH = os.environ.get("VESSL_CONFIG_PATH", os.path.join(DEFAULT_VESSL_DIR, "config"))
 
 
 class ConfigLoader:
@@ -44,6 +42,7 @@ class VesslConfigLoader(ConfigLoader):
                     Optional("default_organization"): str,
                     Optional("default_project"): str,
                     Optional("workspace"): int,
+                    Optional("cluster_kubeconfig"): str,
                 },
                 ignore_extra_keys=True,
             ),
@@ -104,3 +103,15 @@ class VesslConfigLoader(ConfigLoader):
             user["workspace"] = workspace_slug
         self.config["user"] = user
         self.save()
+
+    @property
+    def cluster_kubeconfig(self) -> str:
+        return self.config.get("user", {}).get("cluster_kubeconfig", "")
+
+    @cluster_kubeconfig.setter
+    def cluster_kubeconfig(self, cluster_kubeconfig_path: str):
+        user = self.config.get("user", {})
+        if cluster_kubeconfig_path:
+            user["cluster_kubeconfig"] = cluster_kubeconfig_path
+        self.config["user"] = user
+        self.save()
