@@ -30,8 +30,7 @@ class VesslApiException(VesslException):
         body_code = body.get("code", DEFAULT_ERROR_CODE)
         body_message = body.get("message", "")
         message = (
-            f"{body_code} ({api_exception.status})"
-            f"{': ' + body_message if body_message else ''}"
+            f"{body_code} ({api_exception.status})" f"{': ' + body_message if body_message else ''}"
         )
 
         fields = body.get("fields")
@@ -53,12 +52,19 @@ class VesslApiException(VesslException):
 class VesslRuntimeException(VesslException):
     pass
 
+
 class ClusterAlreadyExistsError(VesslException):
     pass
 
+
 class ClusterNotFoundError(VesslException):
     pass
 
+
+class DependencyError(VesslException):
+    pass
+
+
 class GitError(VesslException):
     pass
 
@@ -121,3 +127,19 @@ class InvalidTypeError(VesslException):
 
 class ImportPackageError(VesslException):
     pass
+
+
+class ContextVariableNotFoundError(VesslException):
+    pass
+
+
+class NotFoundError(VesslException):
+    pass
+
+
+class BadRequestError(VesslException):
+    pass
+
+
+class UnexpectedProblemError(VesslException):
+    pass
