@@ -1,11 +1,16 @@
 import random
 import string
+import uuid
 
 
-def random_string(length=12, punctuations=False):
+def random_string(length=12, punctuations=False) -> str:
     letters = string.ascii_lowercase + string.digits
     if punctuations:
         letters += "!@#$^&"
     return random.SystemRandom().choice(string.ascii_lowercase) + "".join(
         random.SystemRandom().choice(letters) for _ in range(length - 1)
     )
+
+
+def random_uuid():
+    return str(uuid.uuid4())
