@@ -10,6 +10,7 @@ from botocore.session import Session as BotocoreSession
 from vessl import vessl_api
 from vessl.cli._util import sizeof_fmt
 from vessl.util.common import remove_prefix
+from vessl.util.downloader import Downloader
 from vessl.util.exception import (
     InvalidParamsError,
     InvalidVolumeFileError,
@@ -35,6 +36,17 @@ class VolumeFileTransfer:
         self._update_federation_credentials()
 
     def download(self, source_path, dest_path):
+        if self.provider == "gs":
+            result = vessl_api.volume_file_list_api(
+                volume_id=self.volume.id,
+                recursive=True,
+                path=source_path,
+                need_download_url=True,
+            ).results
+            files = sorted(result, key=lambda x: x.path)
+            Downloader.download(source_path, dest_path, *files, quiet=True)
+            return
+
         s3_client = self._get_s3_client()
         (
             file_transmissions,
@@ -100,9 +112,7 @@ class VolumeFileTransfer:
                 )
                 succeeded_count += 1
                 succeeded_size += file_transmission.size
-                succeeded_files.append(
-                    {"path": os.path.basename(file_transmission.dest_abs_path)}
-                )
+                succeeded_files.append({"path": os.path.basename(file_transmission.dest_abs_path)})
             except BaseException as e:
                 print(f"Failed to upload {file_transmission.source_path}.")
                 raise e
@@ -132,9 +142,7 @@ class VolumeFileTransfer:
             total_transmitted += transmitted_bytes
             percent = int(total_transmitted / total_size * 100)
             if percent - interval >= last_percent or percent == 100:
-                print(
-                    f"{sizeof_fmt(total_transmitted)}/{formatted_size} ({percent}%) completed."
-                )
+                print(f"{sizeof_fmt(total_transmitted)}/{formatted_size} ({percent}%) completed.")
                 last_percent = percent
 
         return callback
@@ -166,9 +174,7 @@ class VolumeFileTransfer:
         source_abs_path = f"{self.prefix}/{source_path}" if self.prefix else source_path
         dest_abs_path = os.path.abspath(dest_path)
         try:
-            source_file = vessl_api.volume_file_read_api(
-                volume_id=self.volume.id, path=source_path
-            )
+            source_file = vessl_api.volume_file_read_api(volume_id=self.volume.id, path=source_path)
         except VesslApiException:
             files = vessl_api.volume_file_list_api(
                 volume_id=self.volume.id,
@@ -275,9 +281,7 @@ class VolumeFileTransfer:
                             remove_prefix(source_abs_path, source_path).lstrip("/"),
                         )
                         if self.prefix:
-                            dest_abs_path = os.path.join(
-                                self.prefix, dest_abs_path.lstrip("/")
-                            )
+                            dest_abs_path = os.path.join(self.prefix, dest_abs_path.lstrip("/"))
                         file_size = os.path.getsize(source_abs_path)
                         result.append(
                             FileTransmission(
@@ -291,9 +295,7 @@ class VolumeFileTransfer:
 
                 return result, total_size
 
-            raise InvalidVolumeFileError(
-                f"Destination path is not a directory: {dest_path}."
-            )
+            raise InvalidVolumeFileError(f"Destination path is not a directory: {dest_path}.")
 
     def __get_s3_session_credentials(self):
         federation_credentials = vessl_api.volume_federate_api(volume_id=self.volume.id)
