@@ -21,7 +21,7 @@ class Zipper(zipfile.ZipFile):
 
     def zipdir(self, path, include_dotfiles=False):
         for dir_full_path, dirs, files in os.walk(path):
-            if os.path.basename(dir_full_path) == '.vessl':
+            if os.path.basename(dir_full_path) == ".vessl":
                 continue
 
             if not include_dotfiles:
